..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

==================
 Invenio-PIDStore
==================

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-pidstore.svg
        :target: https://github.com/inveniosoftware/invenio-pidstore/blob/master/LICENSE

.. image:: https://github.com/inveniosoftware/invenio-pidstore/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-pidstore/actions?query=workflow%3ACI

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-pidstore.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-pidstore

.. image:: https://img.shields.io/pypi/v/invenio-pidstore.svg
        :target: https://pypi.org/pypi/invenio-pidstore


Invenio module that mints, stores, registers and resolves persistent
identifiers.

Further documentation is available on https://invenio-pidstore.readthedocs.io/
